@@ -10,6 +10,20 @@
  *   (at your option) any later version; incorporated herein by reference.
  *
  * ----------------------------------------------------------------------- */
+/* ----------------------------------------------------------------------- *
+ *
+ *   02.06.2009 Calculate Pack http://www.calculate-linux.org
+ *
+ *   В исходный код calcreadconfig.c внесены следующие изменения:
+ *   - если параметр .conf или .cfg, то это конфигурационный файл меню
+ *   в остальных случаях параметры аккумулируются в дополнения для передачи
+ *   далее
+ *   - если параметре, значения которого перечислены через запятую возможна
+ *   замена одного из значений (например переходящий параметр test=1,2,3
+ *   test=,,6 заменит в этом параметре последнее занчение => test=1,2,6
+ *   - добавлены функции разбивки и объединения строки
+ *
+ * ----------------------------------------------------------------------- */
 
 #include <stdio.h>
 #include <stdbool.h>
@@ -888,6 +902,8 @@ static void parse_config_file(FILE *f)
 	p = skipspace(p);
 	m->fkeyhelp[fkeyno].background = refstrdup(p);
       }
+    } else if ( looking_at(p, "defaultparam") ) {
+	strncpy(default_tail_cmdline,skipspace(p+12),512);
     } else if ( (ep = looking_at(p, "include")) ) {
     do_include:
       {
@@ -1025,7 +1041,8 @@ static int parse_one_config(const char *filename)
   /* if param is config file (.cfg file) */
   
   if(strlen(filename)>4 && !strcmp(filename+strlen(filename)-4,".cfg") ||
-       strlen(filename)>5 && !strcmp(filename+strlen(filename)-5,".conf") ) {
+       strlen(filename)>5 && !strcmp(filename+strlen(filename)-5,".conf") ||
+       strlen(filename)>12 && !strncmp(filename,"pxelinux.cfg",12) ) {
       f = fopen(filename, "r");
       if( !f )
         if( startconfig[0] ) {
@@ -1122,6 +1139,8 @@ void parse_configs(char **argv)
   const char *filename;
   struct menu *m;
   struct menu_entry *me;
+  default_tail_cmdline[0] = 0;
+  tail_cmdline[0] = 0;
 
   empty_string = refstrdup("");
 
@@ -1141,6 +1160,21 @@ void parse_configs(char **argv)
     while ( (filename = *argv++) )
       parse_one_config(filename);
   }
+  if(strlen(default_tail_cmdline))
+  {
+      char *p = default_tail_cmdline;
+      while(strchr(p,' '))
+      {
+      	*strchr(p,' ')= NULL;
+        if(strlen(p))
+      	    parse_one_config(p);
+      	p += strlen(p)+1;
+      }
+      if(strlen(p))
+      {
+      	parse_one_config(p);
+      }
+  }
 
   /* On final EOF process the last label statement */
   record(current_menu, &ld, append);
